InspectorController class

Singleton

Inheritance
Available extensions

Constructors

InspectorController({bool enabled = false, ShowInspectorOn showInspectorOn = ShowInspectorOn.Shaking, StoppingRequestCallback? onStoppingRequest, StoppingResponseCallback? onStoppingResponse, bool defaultTreeViewEnabled = true, bool defaultExpandChildren = true, bool defaultIsDarkMode = true})
factory

Properties

areAnyFiltersApplied bool
no setter
canLeaveInspectorPage bool
no setter
currentMatchIndex int
no setter
expandChildren bool
no setter
filteredRequestsList List<RequestDetails>
no setter
filterRequestMethod RequestMethod?
no setter
filterStatusCode int?
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
hasRequestStopperFilters bool
no setter
hasResponseStopperFilters bool
no setter
isDarkMode bool
no setter
isInspectorVisible bool
no setter
isSearchVisible bool
no setter
isTreeView bool
no setter
pageController PageController
final
requestsList List<RequestDetails>
no setter
requestStopperEnabled bool
getter/setter pair
requestStopperFilterMethod RequestMethod?
no setter
requestStopperFilterUrl String?
no setter
responseStopperEnabled bool
getter/setter pair
responseStopperFilterStatusCode int?
no setter
responseStopperFilterUrl String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchQuery String
no setter
searchUrlQuery String
no setter
selectedRequest RequestDetails?
getter/setter pair
selectedTab int
getter/setter pair
totalMatches int
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addNewRequest(RequestDetails request) → void
autoLogDeepLinkStream(Stream<Uri> stream, {String action = 'received', Map<String, dynamic>? payload}) StreamSubscription<Uri>

Available on InspectorController, provided by the InspectorLoggingExtensions extension

Auto-log each received deep-link URI from a stream.
autoLogNotificationStream(Stream<Map<String, dynamic>> stream, {String action = 'received', String channel = 'notifications'}) StreamSubscription<Map<String, dynamic>>

Available on InspectorController, provided by the InspectorLoggingExtensions extension

Auto-log each received notification payload from a stream.
clearAllRequests() → void
clearFilters() → void
clearRequestStopperFilters() → void
clearResponseStopperFilters() → void
clearSearch() → void
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
override
editRequest(RequestDetails requestDetails) Future<RequestDetails?>
editResponse(ResponseDetails responseDetails) Future<ResponseDetails?>
hideInspector() → void
logAnalyticsEvent({required String tool, required String eventName, Map<String, dynamic>? payload, int statusCode = 200}) → void

Available on InspectorController, provided by the InspectorLoggingExtensions extension

Log analytics SDK events (Amplitude, Adjust, Insider, Firebase...etc).
logDeepLinkEvent({required Uri deepLink, String action = 'open', Map<String, dynamic>? payload, int statusCode = 200}) → void

Available on InspectorController, provided by the InspectorLoggingExtensions extension

Log deep-link open/parse/navigation events.
logNotificationEvent({required String action, String channel = 'notifications', Map<String, dynamic>? payload, int statusCode = 200}) → void

Available on InspectorController, provided by the InspectorLoggingExtensions extension

Log push/local notification events.
nextMatch() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
previousMatch() → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
runAgain() Future<void>
searchForRequests(String value) → void
setRequestMethodFilter(RequestMethod? method) → void
setRequestStopperFilterMethod(RequestMethod? method) → void
setRequestStopperFilterUrl(String? url) → void
setResponseStopperFilterStatusCode(int? statusCode) → void
setResponseStopperFilterUrl(String? url) → void
setStatusCodeFilter(int? statusCode) → void
shareSelectedRequest({Rect? sharePositionOrigin, ShareType shareType = ShareType.NormalLog}) → void
shouldStopRequest(RequestDetails requestDetails) bool
shouldStopResponse(ResponseDetails responseDetails) bool
showInspector() → void
toggleExpandChildren() → void
toggleInspectorJsonView() → void
toggleInspectorTheme() → void
toggleSearchVisibility() → void
toString() String
A string representation of this object.
inherited
trackAnalyticsEvent<T>({required String tool, required String eventName, Map<String, dynamic>? payload, required FutureOr<T> onTrack(), int statusCode = 200}) Future<T>

Available on InspectorController, provided by the InspectorLoggingExtensions extension

Auto-log analytics when your tracking callback is hit.
updateMatchCount(int count) → void
updateSearchQuery(String query) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited