ResponseDetails class

Constructors

ResponseDetails({required int statusCode, required String url, dynamic headers, dynamic responseBody})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
headers → dynamic
final
responseBody → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final
url String
final

Methods

copyWith({int? statusCode, String? url, dynamic headers, dynamic responseBody}) ResponseDetails
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited